import json

import requests


def extract_informations(headers):
    params = headers['params']
    operations = headers['operations']
    pipeline_id = headers['pipeline']
    step_id = headers['step']
    name = headers['name']
    extension = headers['extension']

    return params, operations, pipeline_id, step_id, name, extension


def resend(body, params, operations, pipeline_id, step_id, consumer_id, core_url, status, reason, name, extension):

    url = f"{core_url}/step?status={status}"

    with open(f"{name}.{extension}", "wb") as image:
        image.write(body)

    with open(f"{name}.{extension}", "rb") as image:
        files = {"media": image}
        content = {"pipeline_id": pipeline_id, "step_id": step_id, "consumer_id": consumer_id, "params": params}
        if reason:
            content['reason'] = reason

        data = {"data": [content]}
        requests.post(url, files=files, data=data)



import click
import coloredlogs

from ..consumer import ReconnectingExampleConsumer
from .main import load_consumer_file, find_consumer_file


@click.command(name='consumer')
@click.option('--file', '-f', default='consumer.py', required=True, help='Consumer file action')
@click.option('--log-level', '-l', default='INFO', help='Log level')
@click.option('--amqp-username', '-u', default='guest', help='AMQP Username')
@click.option('--amqp-password', '-p', default='guest', help='AMQP Password')
@click.option('--amqp-url', '-r', default='localhost', help='AMQP url')
@click.option('--amqp-port', '-P', default=5672, help='AMQP port')
@click.option('--core-url', '-c', default='http://localhost:8888', help='Core server url')
@click.option('--queue-name', '-q', required=True, help='queue name to observe')
def cm(file, log_level, amqp_username, amqp_password, amqp_url, amqp_port, core_url, queue_name):
    coloredlogs.install(level=log_level)
    amqp_url = f'amqp://{amqp_username}:{amqp_password}@{amqp_url}:{amqp_port}/%2F'

    # Load implementation
    consumer_file = find_consumer_file(file)
    _,action_class = load_consumer_file(consumer_file)

    # Launch consumer
    # @Fixme Revoir cette partie pour la découverte de la classe action!
    consumer = ReconnectingExampleConsumer(amqp_url, queue_name, core_url, action_class[list(action_class.keys())[1]]())
    consumer.run()



import setuptools

from version import get_git_version

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="ni-consumers-core",
    version=get_git_version(),
    author="Primael Bruant",
    author_email="primael.bruant@gmail.com",
    description="",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pypa/sampleproject",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        "pika==1.1.0",
        "requests==2.23.0",
        "coloredlogs==14.0",
        "click==7.1.2",
        "ni-logging-utils==0.0.3"
    ],
    entry_points='''
       [console_scripts]
       consumer=consumers_core.cm:cm
    ''',
    python_requires='>=3.6'
)
